import React from 'react';
import { Button, Icon } from '../../../components';
import { Delete, Person } from '@mui/icons-material';
import { Input } from '../../../components/inputs';
import { VISUALIZATION_TYPES } from '../../manager';
import { VisualizationManagerType } from '../../manager';
import { SettingsHeader } from './components';
import { useSessionCache } from '../../../data-access';

type Props = {
  manager: VisualizationManagerType;
};

export function ConfigPanel({ manager }: Props) {
  const session = useSessionCache();

  const buildInfo = import.meta.env.GRAPHPOLARIS_VERSION;

  return (
    <div className="flex flex-col w-full">
      {manager.activeVisualization ? (
        <>
          <div className="border-b py-2">
            <div className="flex justify-between items-center px-4 py-2">
              <span className="text-xs font-bold">Visualization</span>
              <Button
                type="secondary"
                variant="ghost"
                size="xs"
                iconComponent={<Delete />}
                onClick={() => {
                  if (manager.activeVisualization) manager.deleteVisualization(manager.activeVisualization);
                }}
              />
            </div>
            <div className="flex justify-between items-center px-4 py-1">
              <span className="text-xs font-normal">Type</span>
              <div className="w-36">
                <Input type="dropdown" size="xs" options={VISUALIZATION_TYPES} value={manager.activeVisualization} onChange={() => {}} />
              </div>
            </div>
            <div className="flex justify-between items-center px-4 py-1">
              <span className="text-xs font-normal">Name</span>
              <input type="text" className="border rouded text-xs w-36" value={manager.activeVisualization} onChange={() => {}} />
            </div>
          </div>
          {manager.activeVisualization && (
            <div className="border-b p-4 w-full">
              <SettingsHeader name="Configuration" />
              {manager.renderSettings()}
            </div>
          )}
        </>
      ) : (
        <div>
          {session && session.currentSaveState && (
            <div className="flex flex-col p-4 border-b">
              <span className="text-sm font-bold">Connection details</span>
              <span className="text-xs font-semibold">Name</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].name}</span>
              <span className="text-xs font-semibold">Database</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.internalDatabaseName}</span>
              <span className="text-xs font-semibold">Protocol</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.protocol}</span>
              <span className="text-xs font-semibold">Hostname</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.url}</span>
              <span className="text-xs font-semibold">Port</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.port}</span>
            </div>
          )}
        </div>
      )}

      {buildInfo === 'dev' && (
        <div className="mt-auto p-2 bg-light">
          <Button
            type="primary"
            variant="outline"
            size="xs"
            label="Report an issue"
            onClick={() =>
              window.open(
                'https://app.asana.com/-/login?u=https%3A%2F%2Fform.asana.com%2F%3Fk%3D2QEC88Dl7ETs2wYYWjkMXg%26d%3D1206648675960041&error=01',
                '_blank',
              )
            }
            additionalClasses="block w-full"
          />
        </div>
      )}
    </div>
  );
}
