import React, { useEffect } from 'react';
import ReactJSONView from 'react-json-view';
import { VisualizationPropTypes, VISComponentType } from '../../common';
import { GraphMetadata } from '@graphpolaris/shared/lib/data-access/statistics';
import { SettingsContainer } from '@graphpolaris/shared/lib/vis/components/config';
import { Input } from '@graphpolaris/shared/lib/components/inputs';

export interface RawJSONVisProps {
  theme: string;
  iconStyle: string;
}

const configuration: RawJSONVisProps = {
  theme: 'bright:inverted',
  iconStyle: 'circle',
};

export const RawJSONVis = React.memo(({ data, configuration }: VisualizationPropTypes) => {
  return (
    <ReactJSONView
      src={data}
      collapsed={1}
      quotesOnKeys={false}
      style={{ padding: '20px', flexGrow: 1 }}
      theme={configuration.theme}
      iconStyle={configuration.iconStyle}
      enableClipboard={true}
    />
  );
});

const RawJSONSettings = ({
  configuration,
  graph,
  updateSettings,
}: {
  configuration: RawJSONVisProps;
  graph: GraphMetadata;
  updateSettings: (val: any) => void;
}) => {
  return (
    <SettingsContainer>
      <Input
        type="dropdown"
        label="Select a theme"
        value={configuration.theme}
        options={['bright:inverted', 'monokai', 'ocean']}
        onChange={(val) => updateSettings({ theme: val })}
      />
      <Input
        type="dropdown"
        label="Icon style"
        value={configuration.iconStyle}
        options={['circle', 'square', 'triangle']}
        onChange={(val) => updateSettings({ iconStyle: val })}
      />
    </SettingsContainer>
  );
};

export const RawJSONComponent: VISComponentType = {
  displayName: 'RawJSONVis',
  component: RawJSONVis,
  settings: RawJSONSettings,
  configuration: configuration,
};
export default RawJSONComponent;
